# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..registration import AffineRegistration


def test_AffineRegistration_inputs():
    input_map = dict(
        FixedImageFileName=dict(argstr="%s", extensions=None, position=-2,),
        MovingImageFileName=dict(argstr="%s", extensions=None, position=-1,),
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        fixedsmoothingfactor=dict(argstr="--fixedsmoothingfactor %d",),
        histogrambins=dict(argstr="--histogrambins %d",),
        initialtransform=dict(argstr="--initialtransform %s", extensions=None,),
        iterations=dict(argstr="--iterations %d",),
        movingsmoothingfactor=dict(argstr="--movingsmoothingfactor %d",),
        outputtransform=dict(argstr="--outputtransform %s", hash_files=False,),
        resampledmovingfilename=dict(
            argstr="--resampledmovingfilename %s", hash_files=False,
        ),
        spatialsamples=dict(argstr="--spatialsamples %d",),
        translationscale=dict(argstr="--translationscale %f",),
    )
    inputs = AffineRegistration.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_AffineRegistration_outputs():
    output_map = dict(
        outputtransform=dict(extensions=None,),
        resampledmovingfilename=dict(extensions=None,),
    )
    outputs = AffineRegistration.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..resamplescalarvectordwivolume import ResampleScalarVectorDWIVolume


def test_ResampleScalarVectorDWIVolume_inputs():
    input_map = dict(
        Inverse_ITK_Transformation=dict(argstr="--Inverse_ITK_Transformation ",),
        Reference=dict(argstr="--Reference %s", extensions=None,),
        args=dict(argstr="%s",),
        centered_transform=dict(argstr="--centered_transform ",),
        defField=dict(argstr="--defField %s", extensions=None,),
        default_pixel_value=dict(argstr="--default_pixel_value %f",),
        direction_matrix=dict(argstr="--direction_matrix %s", sep=",",),
        environ=dict(nohash=True, usedefault=True,),
        hfieldtype=dict(argstr="--hfieldtype %s",),
        image_center=dict(argstr="--image_center %s",),
        inputVolume=dict(argstr="%s", extensions=None, position=-2,),
        interpolation=dict(argstr="--interpolation %s",),
        notbulk=dict(argstr="--notbulk ",),
        number_of_thread=dict(argstr="--number_of_thread %d",),
        origin=dict(argstr="--origin %s",),
        outputVolume=dict(argstr="%s", hash_files=False, position=-1,),
        rotation_point=dict(argstr="--rotation_point %s",),
        size=dict(argstr="--size %s", sep=",",),
        spaceChange=dict(argstr="--spaceChange ",),
        spacing=dict(argstr="--spacing %s", sep=",",),
        spline_order=dict(argstr="--spline_order %d",),
        transform=dict(argstr="--transform %s",),
        transform_matrix=dict(argstr="--transform_matrix %s", sep=",",),
        transform_order=dict(argstr="--transform_order %s",),
        transformationFile=dict(argstr="--transformationFile %s", extensions=None,),
        window_function=dict(argstr="--window_function %s",),
    )
    inputs = ResampleScalarVectorDWIVolume.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ResampleScalarVectorDWIVolume_outputs():
    output_map = dict(outputVolume=dict(extensions=None, position=-1,),)
    outputs = ResampleScalarVectorDWIVolume.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import LTAConvert


def test_LTAConvert_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        in_fsl=dict(
            argstr="--infsl %s",
            extensions=None,
            mandatory=True,
            xor=("in_lta", "in_fsl", "in_mni", "in_reg", "in_niftyreg", "in_itk"),
        ),
        in_itk=dict(
            argstr="--initk %s",
            extensions=None,
            mandatory=True,
            xor=("in_lta", "in_fsl", "in_mni", "in_reg", "in_niftyreg", "in_itk"),
        ),
        in_lta=dict(
            argstr="--inlta %s",
            mandatory=True,
            xor=("in_lta", "in_fsl", "in_mni", "in_reg", "in_niftyreg", "in_itk"),
        ),
        in_mni=dict(
            argstr="--inmni %s",
            extensions=None,
            mandatory=True,
            xor=("in_lta", "in_fsl", "in_mni", "in_reg", "in_niftyreg", "in_itk"),
        ),
        in_niftyreg=dict(
            argstr="--inniftyreg %s",
            extensions=None,
            mandatory=True,
            xor=("in_lta", "in_fsl", "in_mni", "in_reg", "in_niftyreg", "in_itk"),
        ),
        in_reg=dict(
            argstr="--inreg %s",
            extensions=None,
            mandatory=True,
            xor=("in_lta", "in_fsl", "in_mni", "in_reg", "in_niftyreg", "in_itk"),
        ),
        invert=dict(argstr="--invert",),
        ltavox2vox=dict(argstr="--ltavox2vox", requires=["out_lta"],),
        out_fsl=dict(argstr="--outfsl %s",),
        out_itk=dict(argstr="--outitk %s",),
        out_lta=dict(argstr="--outlta %s",),
        out_mni=dict(argstr="--outmni %s",),
        out_reg=dict(argstr="--outreg %s",),
        source_file=dict(argstr="--src %s", extensions=None,),
        target_conform=dict(argstr="--trgconform",),
        target_file=dict(argstr="--trg %s", extensions=None,),
    )
    inputs = LTAConvert.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_LTAConvert_outputs():
    output_map = dict(
        out_fsl=dict(extensions=None,),
        out_itk=dict(extensions=None,),
        out_lta=dict(extensions=None,),
        out_mni=dict(extensions=None,),
        out_reg=dict(extensions=None,),
    )
    outputs = LTAConvert.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value
